==> smartclientcore7.5.6.zip: docs/constants/interfaces/interfaces/IconProgram.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / IconProgram

# Interface: IconProgram

## Extends

- [`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md)

## Properties

<a id="adparameters" name="adparameters"></a>

### adParameters

> **adParameters**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`adParameters`](constants/interfaces/interfaces/BaseCreative.md#adparameters)

***

<a id="alttext" name="alttext"></a>

### altText

> **altText**: `null` \| `string`

***

<a id="apiframework" name="apiframework"></a>

### apiFramework

> **apiFramework**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`apiFramework`](constants/interfaces/interfaces/BaseCreative.md#apiframework)

***

<a id="clickthroughurl" name="clickthroughurl"></a>

### clickThroughURL

> **clickThroughURL**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`clickThroughURL`](constants/interfaces/interfaces/BaseCreative.md#clickthroughurl)

***

<a id="clicktracker" name="clicktracker"></a>

### clickTracker

> **clickTracker**: `object`[]

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`clickTracker`](constants/interfaces/interfaces/BaseCreative.md#clicktracker)

***

<a id="creativeviewtracker" name="creativeviewtracker"></a>

### creativeViewTracker

> **creativeViewTracker**: [`CreativeViewTracker`](constants/interfaces/interfaces/CreativeViewTracker.md)[]

***

<a id="duration" name="duration"></a>

### duration

> **duration**: `null` \| `number`

***

<a id="hascreative" name="hascreative"></a>

### hasCreative

> **hasCreative**: `boolean`

***

<a id="height" name="height"></a>

### height

> **height**: `null` \| `string`

***

<a id="hovertext" name="hovertext"></a>

### hoverText

> **hoverText**: `null` \| `string`

***

<a id="offset" name="offset"></a>

### offset

> **offset**: `null` \| `number`

***

<a id="program" name="program"></a>

### program

> **program**: `string`

***

<a id="pxratio" name="pxratio"></a>

### pxratio

> **pxratio**: `number`

***

<a id="resources" name="resources"></a>

### resources

> **resources**: [`Resource`](constants/interfaces/interfaces/Resource.md)[]

#### Overrides

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`resources`](constants/interfaces/interfaces/BaseCreative.md#resources)

***

<a id="width" name="width"></a>

### width

> **width**: `null` \| `string`

***

<a id="xposition" name="xposition"></a>

### xPosition

> **xPosition**: `null` \| `string`

***

<a id="yposition" name="yposition"></a>

### yPosition

> **yPosition**: `null` \| `string`

==> smartclientcore7.6.0-dev.zip: docs/constants/interfaces/interfaces/IconProgram.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / IconProgram

# Interface: IconProgram

## Extends

- [`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md)

## Properties

<a id="adparameters" name="adparameters"></a>

### adParameters

> **adParameters**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`adParameters`](constants/interfaces/interfaces/BaseCreative.md#adparameters)

***

<a id="alttext" name="alttext"></a>

### altText

> **altText**: `null` \| `string`

***

<a id="apiframework" name="apiframework"></a>

### apiFramework

> **apiFramework**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`apiFramework`](constants/interfaces/interfaces/BaseCreative.md#apiframework)

***

<a id="clickthroughurl" name="clickthroughurl"></a>

### clickThroughURL

> **clickThroughURL**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`clickThroughURL`](constants/interfaces/interfaces/BaseCreative.md#clickthroughurl)

***

<a id="clicktracker" name="clicktracker"></a>

### clickTracker

> **clickTracker**: [`ClickTracker`](constants/interfaces/interfaces/ClickTracker.md)[] \| [`CreativeViewTracker`](constants/interfaces/interfaces/CreativeViewTracker.md)[] \| [`Tracker`](constants/interfaces/interfaces/Tracker.md)[]

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`clickTracker`](constants/interfaces/interfaces/BaseCreative.md#clicktracker)

***

<a id="creativeviewtracker" name="creativeviewtracker"></a>

### creativeViewTracker

> **creativeViewTracker**: [`CreativeViewTracker`](constants/interfaces/interfaces/CreativeViewTracker.md)[]

***

<a id="duration" name="duration"></a>

### duration

> **duration**: `null` \| `number`

***

<a id="hascreative" name="hascreative"></a>

### hasCreative

> **hasCreative**: `boolean`

***

<a id="height" name="height"></a>

### height

> **height**: `null` \| `string`

***

<a id="hovertext" name="hovertext"></a>

### hoverText

> **hoverText**: `null` \| `string`

***

<a id="offset" name="offset"></a>

### offset

> **offset**: `null` \| `number`

***

<a id="program" name="program"></a>

### program

> **program**: `string`

***

<a id="pxratio" name="pxratio"></a>

### pxratio

> **pxratio**: `number`

***

<a id="resources" name="resources"></a>

### resources

> **resources**: [`Resource`](constants/interfaces/interfaces/Resource.md)[]

#### Overrides

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`resources`](constants/interfaces/interfaces/BaseCreative.md#resources)

***

<a id="width" name="width"></a>

### width

> **width**: `null` \| `string`

***

<a id="xposition" name="xposition"></a>

### xPosition

> **xPosition**: `null` \| `string`

***

<a id="yposition" name="yposition"></a>

### yPosition

> **yPosition**: `null` \| `string`
